"""
__init__.py
"""
__all__ = ["__version__", "__author__", "__description__"]
__version__ = "0.2.3"
__author__ = "Lacides Miranda"
__description__ = "MegaDrive - Genesis Enhanced"
__preffix__ = "md_enhanced"
